package com.buystars.ScreenRecording;
import static android.app.Activity.RESULT_OK;

import android.app.Activity;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.Context;
import android.content.Intent;
import android.media.projection.MediaProjectionManager;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.buystars.R;
import com.buystars.download.ForegroundDownloadService;
import com.facebook.react.bridge.ActivityEventListener;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;

public class ScreenRecordingModule extends ReactContextBaseJavaModule implements ActivityEventListener {
    private static final int REQUEST_CODE = 8088;

    public ScreenRecordingModule(ReactApplicationContext reactContext) {
        super(reactContext);
        reactContext.addActivityEventListener(this); //Register this native module as Activity result listener
    }

    @NonNull
    @Override
    public String getName() {
        return "ScreenRecording";
    }

    @ReactMethod
    public void startRecording() {
        final Activity activity = getCurrentActivity();
        assert activity != null;
        MediaProjectionManager projectionManager = (MediaProjectionManager) activity.getSystemService(Context.MEDIA_PROJECTION_SERVICE);
        Intent captureIntent = projectionManager.createScreenCaptureIntent();
        activity.startActivityForResult(captureIntent, REQUEST_CODE);
    }

    @ReactMethod
    public void stopRecording() {
        final Activity activity = getCurrentActivity();
        assert activity != null;
        Intent serviceIntent = new Intent(activity, ScreenRecordingService.class);
        serviceIntent.setAction("STOP");
        activity.stopService(serviceIntent);
    }

    @Override
    public void onActivityResult(Activity activity, int requestCode, int resultCode, @Nullable Intent intent) {
        if (requestCode == REQUEST_CODE && resultCode == RESULT_OK) {
            int importance = NotificationManager.IMPORTANCE_DEFAULT;
            String channelId = getReactApplicationContext().getString(R.string.screen_recording_channel);
            NotificationManager notificationManager = getReactApplicationContext().getSystemService(NotificationManager.class);
            NotificationChannel channel = null;
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                channel = notificationManager.getNotificationChannel(channelId);
                if (channel == null) {
                    channel = new NotificationChannel(channelId, "Recording", importance);
                    channel.setDescription("Recording Screen");
                    notificationManager.createNotificationChannel(channel);
                }
                Intent serviceIntent = new Intent(activity, ScreenRecordingService.class);
                serviceIntent.setAction("START");
                serviceIntent.putExtra("resultCode", resultCode);
                serviceIntent.putExtra("data", intent);
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                    activity.startForegroundService(serviceIntent);
                }
            }
        }
    }

    @Override
    public void onNewIntent(Intent intent) {

    }
}
